::: laktory.spark.functions._common.COLUMN_OR_NAME
    options:
        show_root_full_path: false
        
::: laktory.spark.functions._common.INT_OR_COLUMN
    options:
        show_root_full_path: false

::: laktory.spark.functions._common.FLOAT_OR_COLUMN
    options:
        show_root_full_path: false

::: laktory.spark.functions._common.STRING_OR_COLUMN
    options:
        show_root_full_path: false
